# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/agent-mafia',
                'doc_host': 'https://jaewilson07.github.io',
                'git_url': 'https://github.com/jaewilson07/agent-mafia',
                'lib_path': 'agent_mafia'},
  'syms': { 'agent_mafia.client.MafiaError': { 'agent_mafia.client.MafiaError.MafiaError': ( 'client/mafiaerror.html#mafiaerror',
                                                                                             'agent_mafia/client/MafiaError.py'),
                                               'agent_mafia.client.MafiaError.MafiaError.__init__': ( 'client/mafiaerror.html#mafiaerror.__init__',
                                                                                                      'agent_mafia/client/MafiaError.py'),
                                               'agent_mafia.client.MafiaError.generate_error_message': ( 'client/mafiaerror.html#generate_error_message',
                                                                                                         'agent_mafia/client/MafiaError.py')},
            'agent_mafia.core': {'agent_mafia.core.foo': ('core.html#foo', 'agent_mafia/core.py')},
            'agent_mafia.utils.chunking': { 'agent_mafia.utils.chunking.calc_end_codeblock': ( 'utils/chunking.html#calc_end_codeblock',
                                                                                               'agent_mafia/utils/chunking.py'),
                                            'agent_mafia.utils.chunking.calc_end_paragraph': ( 'utils/chunking.html#calc_end_paragraph',
                                                                                               'agent_mafia/utils/chunking.py'),
                                            'agent_mafia.utils.chunking.calc_end_sentence': ( 'utils/chunking.html#calc_end_sentence',
                                                                                              'agent_mafia/utils/chunking.py'),
                                            'agent_mafia.utils.chunking.chunk_text': ( 'utils/chunking.html#chunk_text',
                                                                                       'agent_mafia/utils/chunking.py'),
                                            'agent_mafia.utils.chunking.functions_stop_on_value': ( 'utils/chunking.html#functions_stop_on_value',
                                                                                                    'agent_mafia/utils/chunking.py')},
            'agent_mafia.utils.files': { 'agent_mafia.utils.files.read_md_from_disk': ( 'utils/files.html#read_md_from_disk',
                                                                                        'agent_mafia/utils/files.py'),
                                         'agent_mafia.utils.files.upsert_folder': ( 'utils/files.html#upsert_folder',
                                                                                    'agent_mafia/utils/files.py')}}}
